@@ -8,6 +8,7 @@ from sentence_splitter import SentenceSplitter, split_text_into_sentences
 from .diff import dff_text
 from .text_tilling import auto_text_tilling
 from .cut import auto_cut_markdown
+import  logging
 def get_markdown_images(text):
     """
     从markdown中提取图片
@@ -352,7 +353,7 @@ class AutoReWrite(object):
         :param payload:
         :return:
         """
-# http://192.168.1.18:3015/predict
+        # http://192.168.1.18:3015/predict
         paraphrase = self.predict_simplified(payload)
         # print("paraphrase['results']", paraphrase['results'])
         # 开始预测相关性最大的句子
@@ -651,7 +652,7 @@ class AutoReWrite(object):
                     if type(out)==dict and out['results'][0][0][0]['summary_text'] is not None:
 
                         item["results"]=out['results'][0][0][0]['summary_text']
-
+            logging.info("rewriter_by_summary:",item)
             yield item
         #     newdata.append(item)
 
@@ -667,14 +668,15 @@ def rewriter_by_summary(text,auto_sample=False,simlimit=0.6,temperature=1.2,api=
     # text= auto_text_tilling(text)
     rewriter = AutoReWrite(api=api,api_sbert_host=api_sbert_host)
     # for temperature in [1.2]:
-    out = rewriter.rewriter_by_summary(text, simlimit=0.6, simlimitmax=0.999999999, auto_sample=False,temperature=temperature)
+    for item in rewriter.rewriter_by_summary(text, simlimit=0.6, simlimitmax=0.999999999, auto_sample=False,temperature=temperature):
+        yield item
 
     # text="\n ".join(out['items'])
     # text= auto_text_tilling(text)
     # # 提取图片信息
     # text_list,images=get_markdown_images_format(text)
     # return text_list,images
-    return out
+    # return out
 
 if __name__ == "__main__":
     # payload = {"config": {
